EXPORTS
	??0CPKIXCertChainBase@@IAE@XZ @ 1 NONAME ; CPKIXCertChainBase::CPKIXCertChainBase(void)
	??0CPKIXValidationResultBase@@IAE@XZ @ 2 NONAME ; CPKIXValidationResultBase::CPKIXValidationResultBase(void)
	??1CPKIXCertChainBase@@UAE@XZ @ 3 NONAME ; CPKIXCertChainBase::~CPKIXCertChainBase(void)
	??1CPKIXValidationResultBase@@UAE@XZ @ 4 NONAME ; CPKIXValidationResultBase::~CPKIXValidationResultBase(void)
	?AddCertL@CPKIXCertChainBase@@QAEXABVTPtrC8@@@Z @ 5 NONAME ; void CPKIXCertChainBase::AddCertL(class TPtrC8 const &)
	?CancelValidate@CPKIXCertChainBase@@QAEXXZ @ 6 NONAME ; void CPKIXCertChainBase::CancelValidate(void)
	?ChainHasRoot@CPKIXCertChainBase@@QBEHXZ @ 7 NONAME ; int CPKIXCertChainBase::ChainHasRoot(void) const
	?ConstructL@CPKIXCertChainBase@@IAEXAAVMCertStore@@ABVTPtrC8@@ABV?$RPointerArray@VCX509Certificate@@@@@Z @ 8 NONAME ; void CPKIXCertChainBase::ConstructL(class MCertStore &, class TPtrC8 const &, class RPointerArray<class CX509Certificate> const &)
	?ConstructL@CPKIXCertChainBase@@IAEXAAVMCertStore@@ABVTPtrC8@@VTUid@@@Z @ 9 NONAME ; void CPKIXCertChainBase::ConstructL(class MCertStore &, class TPtrC8 const &, class TUid)
	?ConstructL@CPKIXValidationResultBase@@IAEXXZ @ 10 NONAME ; void CPKIXValidationResultBase::ConstructL(void)
	?Error@CPKIXValidationResultBase@@QBE?BVTValidationStatus@@XZ @ 11 NONAME ; class TValidationStatus const CPKIXValidationResultBase::Error(void) const
	?NewL@CPKIXCertChainBase@@SAPAV1@AAVMCertStore@@ABVTPtrC8@@ABV?$RPointerArray@VCX509Certificate@@@@@Z @ 12 NONAME ; class CPKIXCertChainBase * CPKIXCertChainBase::NewL(class MCertStore &, class TPtrC8 const &, class RPointerArray<class CX509Certificate> const &)
	?NewL@CPKIXCertChainBase@@SAPAV1@AAVMCertStore@@ABVTPtrC8@@VTUid@@@Z @ 13 NONAME ; class CPKIXCertChainBase * CPKIXCertChainBase::NewL(class MCertStore &, class TPtrC8 const &, class TUid)
	?NewL@CPKIXValidationResultBase@@SAPAV1@XZ @ 14 NONAME ; class CPKIXValidationResultBase * CPKIXValidationResultBase::NewL(void)
	?NewLC@CPKIXCertChainBase@@SAPAV1@AAVMCertStore@@ABVTPtrC8@@ABV?$RPointerArray@VCX509Certificate@@@@@Z @ 15 NONAME ; class CPKIXCertChainBase * CPKIXCertChainBase::NewLC(class MCertStore &, class TPtrC8 const &, class RPointerArray<class CX509Certificate> const &)
	?NewLC@CPKIXCertChainBase@@SAPAV1@AAVMCertStore@@ABVTPtrC8@@VTUid@@@Z @ 16 NONAME ; class CPKIXCertChainBase * CPKIXCertChainBase::NewLC(class MCertStore &, class TPtrC8 const &, class TUid)
	?NewLC@CPKIXValidationResultBase@@SAPAV1@XZ @ 17 NONAME ; class CPKIXValidationResultBase * CPKIXValidationResultBase::NewLC(void)
	?Policies@CPKIXValidationResultBase@@QBEABV?$CArrayPtrFlat@VCX509CertPolicyInfo@@@@XZ @ 18 NONAME ; class CArrayPtrFlat<class CX509CertPolicyInfo> const & CPKIXValidationResultBase::Policies(void) const
	?ValidateL@CPKIXCertChainBase@@QAEXAAVCPKIXValidationResultBase@@ABVTTime@@AAVTRequestStatus@@@Z @ 19 NONAME ; void CPKIXCertChainBase::ValidateL(class CPKIXValidationResultBase &, class TTime const &, class TRequestStatus &)
	?ValidateL@CPKIXCertChainBase@@QAEXAAVCPKIXValidationResultBase@@ABVTTime@@ABV?$CArrayPtr@VHBufC16@@@@AAVTRequestStatus@@@Z @ 20 NONAME ; void CPKIXCertChainBase::ValidateL(class CPKIXValidationResultBase &, class TTime const &, class CArrayPtr<class HBufC16> const &, class TRequestStatus &)
	?Warnings@CPKIXValidationResultBase@@QBEABV?$CArrayFixFlat@VTValidationStatus@@@@XZ @ 21 NONAME ; class CArrayFixFlat<class TValidationStatus> const & CPKIXValidationResultBase::Warnings(void) const
	?ExternalizeL@CPKIXValidationResultBase@@QBEXAAVRWriteStream@@@Z @ 22 NONAME ; void CPKIXValidationResultBase::ExternalizeL(class RWriteStream &) const
	?InternalizeL@CPKIXValidationResultBase@@QAEXAAVRReadStream@@@Z @ 23 NONAME ; void CPKIXValidationResultBase::InternalizeL(class RReadStream &)
	?AddSupportedCriticalExtensionsL@CPKIXCertChainBase@@QAEXABV?$RPointerArray@VTDesC16@@@@@Z @ 24 NONAME ; void CPKIXCertChainBase::AddSupportedCriticalExtensionsL(class RPointerArray<class TDesC16> const &)
	?AppendCertificateValidationObjectL@CPKIXValidationResultBase@@QAEXABVCCertificateValidationWarnings@@@Z @ 25 NONAME ; void CPKIXValidationResultBase::AppendCertificateValidationObjectL(class CCertificateValidationWarnings const &)
	?AppendCriticalExtensionWarningL@CPKIXValidationResultBase@@QAEXAAVTDesC16@@@Z @ 26 NONAME ; void CPKIXValidationResultBase::AppendCriticalExtensionWarningL(class TDesC16 &)
	?RemoveSupportedCriticalExtensions@CPKIXCertChainBase@@QAEXABV?$RPointerArray@VTDesC16@@@@@Z @ 27 NONAME ; void CPKIXCertChainBase::RemoveSupportedCriticalExtensions(class RPointerArray<class TDesC16> const &)
	?ResetSupportedCriticalExtsToDefaultL@CPKIXCertChainBase@@QAEXXZ @ 28 NONAME ; void CPKIXCertChainBase::ResetSupportedCriticalExtsToDefaultL(void)
	?SetSupportedCriticalExtensionsL@CPKIXCertChainBase@@QAEXABV?$RPointerArray@VTDesC16@@@@@Z @ 29 NONAME ; void CPKIXCertChainBase::SetSupportedCriticalExtensionsL(class RPointerArray<class TDesC16> const &)
	?SetValidityPeriodCheckFatal@CPKIXCertChainBase@@QAEXH@Z @ 30 NONAME ; void CPKIXCertChainBase::SetValidityPeriodCheckFatal(int)
	?SupportedCriticalExtensions@CPKIXCertChainBase@@QBEABV?$RPointerArray@VTDesC16@@@@XZ @ 31 NONAME ; class RPointerArray<class TDesC16> const & CPKIXCertChainBase::SupportedCriticalExtensions(void) const
	?ValidationWarnings@CPKIXValidationResultBase@@QBEABV?$RPointerArray@VCCertificateValidationWarnings@@@@XZ @ 32 NONAME ; class RPointerArray<class CCertificateValidationWarnings> const & CPKIXValidationResultBase::ValidationWarnings(void) const
	?ValidityPeriodCheckFatal@CPKIXCertChainBase@@QBEHXZ @ 33 NONAME ; int CPKIXCertChainBase::ValidityPeriodCheckFatal(void) const

